.. Copyright (C) 2019, Nokia

.. image:: https://travis-ci.org/nokia/crl-interactivesessions.svg?branch=master
    :target: https://travis-ci.org/nokia/crl-interactivesessions

README
======

``crl.interactivesession`` is a library for interactive shell commands via
*pexpect*. It also provides plug-in interface for tailoring shells.

Documentation
-------------

Documentation for ``crl.interactivesessions`` can be found from `Read The Docs`_.

.. _Read The Docs: http://crl-interactivesessions.readthedocs.io/

Installation
------------

The package can be installed with pip::

  # pip install crl.interactivesessions

Contributing
------------

Please see contributing_ for development and contribution practices.

The code_ and the issues_ are hosted on GitHub.

The project is licensed under BSD-3-Clause_.

.. _contributing: https://github.com/nokia/crl-interactivesessions/blob/master/CONTRIBUTING.rst
.. _code: https://github.com/nokia/crl-interactivesessions
.. _issues: https://github.com/nokia/crl-interactivesessions/issues
.. _BSD-3-Clause:  https://github.com/nokia/crl-interactivesessions/blob/master/LICENSE
